@@ -2,5 +2,5 @@
 
 from __future__ import unicode_literals
 
-from .simplified import CHARACTERS as SIMPLIFIED
-from .traditional import CHARACTERS as TRADITIONAL
+from .simplified import CHARACTERS as simplified
+from .traditional import CHARACTERS as traditional
